@@ -11,6 +11,7 @@
 
 class QColor;
 class QDateTime;
+class QImage;
 class QVariant;
 
 /** Misc utilities. */
@@ -39,16 +40,16 @@ public:
     /** Execute the non-exported sort() method on a QAbstractItemModel. */
     Q_INVOKABLE static void sortModel(QObject *model, int column, Qt::SortOrder sortOrder);
 
-    /** Determine the aspect ratio of an SVG file.
-     *  This is a dirty workaround for the problem that Kirigami.Icon has its implicit size hardcoded to 32x32...
-     */
-    Q_INVOKABLE static float svgAspectRatio(const QString &svgFilePath);
-
     /** QColor::isValid for QML. */
     Q_INVOKABLE static bool isValidColor(const QColor &color);
 
     /** Expose LocationUtil::isLocationCahnge to QML. */
     Q_INVOKABLE static bool isLocationChange(const QVariant &res);
+
+    /** Simple heuristic on whether @p is primarily dark (and thus needs a light text
+     *  color to be readable on top).
+     */
+    Q_INVOKABLE static bool isDarkImage(const QImage &img);
 };
 
 #endif // UTIL_H
